from setuptools import setup

setup(name='akr_probability',
      version='0.1',
      description='Gaussian akr_probability',
      packages=['akr_probability'],
      author='Arishwin Kishaan',
      author_email='arishwinkishaan3@gmail.com',
      zip_safe=False)